# CCMM-Invenio: CCMM runtime library for NRP Invenio

This library provides:

* Fixtures for vocabularies to support the CCMM model in NRP Invenio
* Schema serializers for the CCMM model
* Import and export modules for the CCMM model
* UI components for working with the CCMM model in NRP Invenio

## Installation

```bash
pip install ccmm-invenio
```

## Usage

```bash
invenio oarepo fixtures load
```
